/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.thread;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

import org.junit.Test;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ConcurrentHashMapWithDefaultsTest {

    @Test
    public void testGetValueOrDefaultReturnsOwnValue() throws Exception {
        ConcurrentHashMapWithDefaults<String, Object> defaultMap = new ConcurrentHashMapWithDefaults<String, Object>();
        defaultMap.put("key1", new Integer(11));
        ConcurrentHashMapWithDefaults<String, Object> map = new ConcurrentHashMapWithDefaults<String, Object>(
                defaultMap);
        map.put("key1", new Integer(1));
        assertEquals(1, map.getValueOrDefault("key1"));
    }

    @Test
    public void testGetValueOrDefaultReturnsDefaultValue() {
        ConcurrentHashMapWithDefaults<String, Object> defaultMap = new ConcurrentHashMapWithDefaults<String, Object>();
        defaultMap.put("key1", new Integer(11));
        ConcurrentHashMapWithDefaults<String, Object> map = new ConcurrentHashMapWithDefaults<String, Object>(
                defaultMap);
        assertEquals(11, map.getValueOrDefault("key1"));
    }

    @Test
    public void testGetValueOrDefaultReturnsDefaultValueAfterRemoveOnOverridenValue() {
        ConcurrentHashMapWithDefaults<String, Object> defaultMap = new ConcurrentHashMapWithDefaults<String, Object>();
        defaultMap.put("key1", new Integer(11));
        ConcurrentHashMapWithDefaults<String, Object> map = new ConcurrentHashMapWithDefaults<String, Object>(
                defaultMap);
        map.put("key1", new Integer(1));
        assertEquals(1, map.getValueOrDefault("key1"));
        map.remove("key1");
        assertEquals(11, map.getValueOrDefault("key1"));
    }

    
    @Test
    public void testGetValueOrDefaultReturnsNullValue() {
        ConcurrentHashMapWithDefaults<String, Object> defaultMap = new ConcurrentHashMapWithDefaults<String, Object>();
        ConcurrentHashMapWithDefaults<String, Object> map = new ConcurrentHashMapWithDefaults<String, Object>(
                defaultMap);
        assertNull(map.getValueOrDefault("key1"));
    }

}
