/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.thread;

import org.junit.Test;

import static org.junit.Assert.*;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class TestThreadTest {
    
    @Test
    public void testTestThreadNothingThrown() throws Throwable {
        TestThread testThread = new TestThread(new Runnable() {
            @Override
            public void run() {
            }
        });
        testThread.joinExplosively();
    }
    
    @Test
    public void testTestThreadErrorThrown() throws Exception {
        final OutOfMemoryError thrown = new OutOfMemoryError("This should cause test failure!");
        
        TestThread testThread = new TestThread(new Runnable() {
            @Override
            public void run() {
                throw thrown;
            }
        });
        
        try {
            testThread.joinExplosively();
        } catch (Throwable e) {
            assertSame(thrown, e);
        }
    }

    @Test
    public void testTestThreadRuntimeExceptionThrown() throws Exception {
        final RuntimeException thrown = new RuntimeException("This should cause test failure!");
        
        TestThread testThread = new TestThread(new Runnable() {
            @Override
            public void run() {
                throw thrown;
            }
        });
        
        try {
            testThread.joinExplosively();
        } catch (Throwable e) {
            assertSame(thrown, e);
        }
    }

    
    
    
}
