/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.thread;

import java.util.concurrent.Semaphore;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class WaitingTask implements Runnable {

    private Object starterMonitor;

    private Semaphore readyMonitor;

    private Runnable taskToRun;

    protected WaitingTask(Runnable taskToRun) {
        super();
        this.taskToRun = taskToRun;
    }

    @Override
    public void run() {
        try {
            synchronized (this.starterMonitor) {
                this.readyMonitor.release();
                this.starterMonitor.wait();
            }
            taskToRun.run();
        } catch (InterruptedException e) {
            throw new UncheckedException(e);
        } finally {
            this.readyMonitor.release();
        }

    }

    protected void init(Semaphore readyMonitor, Object starterMonitor) {
        this.starterMonitor = starterMonitor;
        this.readyMonitor = readyMonitor;
    }

}
